@@ -54,7 +54,7 @@ type ScrapePools = {
 };
 
 const poolPanelHealthClass = (pool: ScrapePool) =>
-  pool.count > 1 && pool.downCount === pool.count
+  pool.count > 0 && pool.downCount === pool.count
     ? panelClasses.panelHealthErr
     : pool.downCount >= 1
       ? panelClasses.panelHealthWarn
@@ -167,7 +167,7 @@ const ScrapePoolList: FC<ScrapePoolListProp> = ({
   const dispatch = useAppDispatch();
   const [showEmptyPools, setShowEmptyPools] = useLocalStorage<boolean>({
     key: "targetsPage.showEmptyPools",
-    defaultValue: true,
+    defaultValue: false,
   });
 
   const { collapsedPools, showLimitAlert } = useAppSelector(
